pub trait QueryArgs: Send + Sync {
// Required method
fn encode(&self, encoder: &mut Encoder<'_>) -> Result<(), Error>;
}Expand description
A tuple of query arguments.
This trait is implemented for tuples of sizes up to twelve. You can derive it for a structure in this case it’s treated as a named tuple (i.e. query should include named arguments rather than numeric ones).
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".